@@ -22,21 +22,8 @@
 #   
 # 
 
-[ -f ".last_built" ] || touch .last_built
-
-[ "`cat .last_built`" != "`hostname`" ] && echo "Cleaning (last built on different host)" && rm -rf build/
-
 waf=./waf
 target=${HOME}/Progetti/ejecter/test
 
-if [ "$1" ]; then
-    export VALAC=`pwd`/../vala/$1/bin/valac
-else
-    export VALAC=valac
-fi
-
-echo -n "Using "
-${VALAC} --version
-
-$waf configure --prefix=$target --debug && $waf && $waf install && hostname > .last_built && $target/bin/ejecter
+$waf configure --prefix=$target --debug && $waf $1 && $waf $1 install && $target/bin/ejecter
 
